package vc.thinker.config.akka;

import akka.actor.ActorSystem;
import com.typesafe.config.Config;
import com.typesafe.config.ConfigFactory;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.context.ApplicationContext;
import org.springframework.context.annotation.Bean;
import org.springframework.context.annotation.Configuration;
import org.springframework.context.annotation.Lazy;
import vc.thinker.config.akka.extension.SpringExtension;
import vc.thinker.utils.SpringContextHolder;

/**
 * @author : xieshaojun
 * @date : 2023/1/3 17:47
 */
@Configuration
public class AkkaConfig {
    @Autowired
    private ApplicationContext applicationContext;

    @Bean
    @Lazy(false)
    public SpringContextHolder springContextHolder() {
        return new SpringContextHolder();
    }

    /**
     * Akka配置
     *
     * @return
     */
    @Bean
    public Config akkaConfiguration() {
        return ConfigFactory.load();
    }

    /**
     * spring 集成Akka
     *
     * @return
     */
    @Bean
    public SpringExtension springExtension() {
        return new SpringExtension();
    }

    /**
     * Actor system singleton for this application.
     */
    @Bean
    public ActorSystem actorSystem() {
        ActorSystem system = ActorSystem.create("AkkaTaskProcessing", akkaConfiguration());
        springExtension().initialize(applicationContext);
        return system;
    }
}

